@@ -1,6 +1,6 @@
 // DistributionSocketLink.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011, 2012 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -98,6 +98,7 @@ DistributionSocketLink::init()
   // Read all tcp link configuration.
   read_configuration();
   configurator->add_listener(CoreConfig::CFG_KEY_DISTRIBUTION_TCP, this);
+  configurator->add_listener(CoreConfig::CFG_KEY_DISTRIBUTION, this);
 
   TRACE_EXIT();
 }
@@ -109,6 +110,7 @@ DistributionSocketLink::heartbeat()
 {
   if (server_enabled)
     {
+      TRACE_ENTER("DistributionSocketLink::heartbeat");
       heartbeat_count++;
 
       time_t current_time = time(NULL);
@@ -150,6 +152,7 @@ DistributionSocketLink::heartbeat()
         {
           send_client_message(DCMT_MASTER);
         }
+      TRACE_EXIT();
     }
 }
 
@@ -165,7 +168,7 @@ DistributionSocketLink::init_my_id()
   if (Util::file_exists(idfilename))
     {
       ifstream file(idfilename.c_str());
-      
+
       if (file)
         {
           string id_str;
@@ -173,7 +176,7 @@ DistributionSocketLink::init_my_id()
 
           if (id_str.length() == WRID::STR_LENGTH)
             {
-              ok = my_id.set(id_str);              
+              ok = my_id.set(id_str);
             }
           file.close();
         }
@@ -225,11 +228,12 @@ DistributionSocketLink::get_number_of_peers()
 void
 DistributionSocketLink::connect(string url)
 {
+  TRACE_ENTER_MSG("DistributionSocketLink::connect", url);
   if (network_enabled)
     {
       std::string::size_type pos = url.find("://");
       std::string hostport;
-      
+
       if (pos == std::string::npos)
         {
           hostport = url;
@@ -238,11 +242,11 @@ DistributionSocketLink::connect(string url)
         {
           hostport = url.substr(pos + 3);
         }
-      
+
       pos = hostport.rfind(":");
       std::string host;
       std::string port = "0";
-      
+
       if (pos == std::string::npos)
         {
           host = hostport;
@@ -252,9 +256,10 @@ DistributionSocketLink::connect(string url)
           host = hostport.substr(0, pos);
           port = hostport.substr(pos + 1);
         }
-       
+
       add_client(NULL, (gchar *)host.c_str(), atoi(port.c_str()), CLIENTTYPE_DIRECT);
     }
+  TRACE_EXIT();
 }
 
 
@@ -277,6 +282,7 @@ DistributionSocketLink::disconnect(string id)
 bool
 DistributionSocketLink::disconnect_all()
 {
+  TRACE_ENTER("DistributionSocketLink::disconnect_all");
   list<Client *>::iterator i = clients.begin();
   bool ret = false;
 
@@ -291,6 +297,7 @@ DistributionSocketLink::disconnect_all()
 
   set_me_master();
 
+  TRACE_EXIT();
   return ret;
 }
 
@@ -299,6 +306,7 @@ DistributionSocketLink::disconnect_all()
 bool
 DistributionSocketLink::reconnect_all()
 {
+  TRACE_ENTER("DistributionSocketLink::reconnect_all");
   list<Client *>::iterator i = clients.begin();
   bool ret = false;
 
@@ -312,6 +320,7 @@ DistributionSocketLink::reconnect_all()
       i++;
     }
 
+  TRACE_EXIT();
   return ret;
 }
 
@@ -363,11 +372,13 @@ DistributionSocketLink::set_lock_master(bool lock)
 void
 DistributionSocketLink::set_user(string user, string pw)
 {
+  TRACE_ENTER_MSG("DistributionSocketLink::set_user", user << " " << pw);
   g_free(username);
   g_free(password);
 
   username = g_strdup(user.c_str());
   password = g_strdup(pw.c_str());
+  TRACE_EXIT();
 }
 
 
@@ -392,7 +403,7 @@ DistributionSocketLink::set_network_enabled(bool enabled)
   else if (!network_enabled && enabled)
     {
       network_enabled = enabled;
-      
+
       set_server_enabled(server_enabled);
     }
 
@@ -533,7 +544,7 @@ DistributionSocketLink::add_client(gchar *id, gchar *host, gint port, ClientType
                   (host != NULL ? host : "NULL")  << " " << port);
 
   gchar *canonical_host = NULL;
-  
+
   Client *c = find_client_by_canonicalname(host, port);
   if (c != NULL && c->type == CLIENTTYPE_SIGNEDOFF && type == CLIENTTYPE_DIRECT)
     {
@@ -550,12 +561,12 @@ DistributionSocketLink::add_client(gchar *id, gchar *host, gint port, ClientType
           c->socket->close();
           delete c->socket;
         }
-      
+
       ISocket *socket = socket_driver->create_socket();
       socket->set_data(c);
       socket->set_listener(this);
       socket->connect(host, port);
-      
+
       c->socket = socket;
     }
   else
@@ -587,12 +598,12 @@ DistributionSocketLink::add_client(gchar *id, gchar *host, gint port, ClientType
               client->socket->close();
               delete client->socket;
             }
-          
+
           ISocket *socket = socket_driver->create_socket();
           socket->set_data(client);
           socket->set_listener(this);
           socket->connect(host, port);
-          
+
           client->socket = socket;
         }
     }
@@ -686,6 +697,7 @@ DistributionSocketLink::set_client_id(Client *client, gchar *id)
 void
 DistributionSocketLink::remove_client(Client *client)
 {
+  TRACE_ENTER("DistributionSocketLink::remove_client");
   list<Client *>::iterator i = clients.begin();
 
   while (i != clients.end())
@@ -696,7 +708,7 @@ DistributionSocketLink::remove_client(Client *client)
             {
               dist_manager->signoff_remote_client((*i)->id);
             }
-          
+
           dist_manager->log(_("Removing client %s."),
                             (*i)->id == NULL ? "Unknown" : (*i)->id);
           delete *i;
@@ -713,6 +725,7 @@ DistributionSocketLink::remove_client(Client *client)
       // Client to be removed is master. Unset master client.
       master_client = NULL;
     }
+  TRACE_EXIT();
 }
 
 
@@ -737,7 +750,7 @@ DistributionSocketLink::remove_peer_clients(Client *client)
             {
               dist_manager->signoff_remote_client((*i)->id);
             }
-          
+
           if (client == master_client)
             {
               // Connection to master is lost. Unset master client.
@@ -760,14 +773,14 @@ DistributionSocketLink::remove_peer_clients(Client *client)
 void
 DistributionSocketLink::close_client(Client *client, bool reconnect /* = false*/)
 {
-  TRACE_ENTER_MSG("DistributionSocketLink::close_client", 
+  TRACE_ENTER_MSG("DistributionSocketLink::close_client",
 	  (client->id != NULL ? client->id : "Unknown") << " " << reconnect);
 
   if (client->id != NULL)
     {
       dist_manager->signoff_remote_client(client->id);
     }
-  
+
   if (client == master_client)
     {
       // Client to be closed is master. Unset master client.
@@ -826,6 +839,7 @@ DistributionSocketLink::close_client(Client *client, bool reconnect /* = false*/
 
       remove_peer_clients(client);
     }
+  TRACE_EXIT();
 }
 
 
@@ -1013,7 +1027,14 @@ DistributionSocketLink::send_packet_except(PacketBuffer &packet, Client *client)
       if (c != client && c->socket != NULL)
         {
           int bytes_written = 0;
-          c->socket->write(packet.get_buffer(), size, bytes_written);
+          try
+            {
+              c->socket->write(packet.get_buffer(), size, bytes_written);
+            }
+          catch (SocketException)
+            {
+              TRACE_MSG("Failed to send");
+            }
         }
       i++;
     }
@@ -1067,7 +1088,14 @@ DistributionSocketLink::send_packet(Client *client, PacketBuffer &packet)
       packet.poke_ushort(0, size);
 
       int bytes_written = 0;
-      client->socket->write(packet.get_buffer(), size, bytes_written);
+      try
+        {
+          client->socket->write(packet.get_buffer(), size, bytes_written);
+        }
+      catch (SocketException)
+        {
+          TRACE_MSG("Failed to send");
+        }
     }
 
   TRACE_EXIT();
@@ -1387,7 +1415,7 @@ DistributionSocketLink::handle_signoff(PacketBuffer &packet, Client *client)
           TRACE_MSG("Direct connection. setting signedoff");
           c->type = CLIENTTYPE_SIGNEDOFF;
           remove_peer_clients(c);
-          
+
           if (c->socket != NULL)
             {
               TRACE_MSG("Remove connection");
@@ -2001,7 +2029,7 @@ DistributionSocketLink::start_async_server()
     {
       /* Create the server */
       server_socket = socket_driver->create_server();
-      
+
       if (server_socket != NULL)
         {
           server_socket->set_listener(this);
@@ -2013,7 +2041,7 @@ DistributionSocketLink::start_async_server()
   catch(SocketException e)
     {
     }
-  
+
   TRACE_RETURN(ret);
   return ret;
 }
@@ -2199,6 +2227,7 @@ DistributionSocketLink::socket_closed(ISocket *con, void *data)
 void
 DistributionSocketLink::read_configuration()
 {
+  TRACE_ENTER("DistributionSocketLink::read_configuration");
   int old_port = server_port;
 
   const char *port = getenv("WORKRAVE_PORT");
@@ -2226,6 +2255,7 @@ DistributionSocketLink::read_configuration()
 
   str = dist_manager->get_password();
   password = str != "" ? g_strdup(str.c_str()) : NULL;
+  TRACE_EXIT();
 }
 
 
