@@ -21,6 +21,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
+#include <gdk/gdk.h>
 
 #include "eggsmclient.h"
 #include "eggsmclient-private.h"
@@ -116,7 +117,7 @@ egg_sm_client_class_init (EggSMClientClass *klass)
    * handling this signal; if the user has requested that the session
    * be saved when logging out, then ::save_state will be emitted
    * separately.
-   * 
+   *
    * If the application agrees to quit, it should then wait for either
    * the ::quit_cancelled or ::quit signals to be emitted.
    **/
@@ -347,7 +348,7 @@ egg_sm_client_get (void)
 # ifdef EGG_SM_CLIENT_BACKEND_XSMP
 	  global_client = egg_sm_client_xsmp_new ();
 # endif
-# ifdef EGG_SM_CLIENT_BACKEND_DBUS
+# if defined(EGG_SM_CLIENT_BACKEND_DBUS) && !defined(PLATFORM_OS_WIN32)
 	  if (!global_client)
 	    global_client = egg_sm_client_dbus_new ();
 # endif
