@@ -1,6 +1,6 @@
 // DesktopWindow.cc --- Desktop window
 //
-// Copyright (C) 2004, 2007 Rob Caelers & Raymond Penners
+// Copyright (C) 2004, 2007, 2012, 2013 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -17,6 +17,10 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "DesktopWindow.hh"
 #include "W32Compat.hh"
 #include "debug.hh"
@@ -34,26 +38,26 @@ DesktopWindow::DesktopWindow(const HeadInfo &head)
   int x = head.get_x(), y = head.get_y();
   int w = head.get_width(), h = head.get_height();
 
+  TRACE_MSG("Head: " << x << ", " << y << ", " << w << ", " << h << " " << head.monitor);
+
   POINT pt = { x, y };
-  HMONITOR monitor = W32Compat::MonitorFromPoint(pt, MONITOR_DEFAULTTONULL);
+  HMONITOR monitor = MonitorFromPoint(pt, MONITOR_DEFAULTTONULL);
   if (monitor)
 	{
 	  TRACE_MSG("Monitor found");
-	  MONITORINFO info;
-	  info.cbSize = sizeof(MONITORINFO);
+      MONITORINFO info = { 0, };
+	  info.cbSize = sizeof(info);
 
-	  if (W32Compat::GetMonitorInfo(monitor, &info))
+	  if (GetMonitorInfo(monitor, &info))
 		{
 		  x = info.rcMonitor.left;
 		  y = info.rcMonitor.top;
 		  w = info.rcMonitor.right - x;
 		  h = info.rcMonitor.bottom - y;
-		  TRACE_MSG("Monitor dimensions: " << x << ", " << y << ", " << w << ", " << h);
+		  TRACE_MSG("Monitor: " << x << ", " << y << ", " << w << ", " << h);
 		}
 	}
 
-
-
   hwnd = CreateWindowEx(WS_EX_TOOLWINDOW,
                         WINDOW_CLASS,
                         WINDOW_CLASS,
