@@ -132,18 +132,19 @@ GUI::main()
   __try1(exception_handler);
 #endif
 
-#ifdef PLATFORM_OS_WIN32
-  System::init();
-#else
-  System::init(NULL);
-#endif
-
   g_type_init();
 
   init_debug();
   init_core();
   init_sound_player();
 
+  #ifdef PLATFORM_OS_WIN32
+  System::init();
+#else
+  System::init(NULL);
+#endif
+
+
   // The main status window.
   main_window = new MainWindow();
 
@@ -161,6 +162,7 @@ GUI::main()
   delete main_window;
   main_window = NULL;
 
+  System::clear();
 #ifdef PLATFORM_OS_WIN32
   // Disable Windows structural exception handling.
   __except1;
@@ -307,7 +309,7 @@ GUI::new_break_window(BreakId break_id, bool user_initiated)
   bool ignorable = true;
 
   (void) user_initiated;
-  
+
   if (break_id == BREAK_ID_MICRO_BREAK)
     {
       ret = new BreakWindow(break_id, ignorable, block_mode);
